@@ -11,7 +11,7 @@
 # this file, and for a DISCLAIMER OF ALL WARRANTIES.
 
 # Verify that we have Tk binary and script components from the same release
-package require -exact Tk  8.6.9
+package require -exact Tk  8.6.10
 
 # Create a ::tk namespace
 namespace eval ::tk {
@@ -462,7 +462,8 @@ switch -exact -- [tk windowingsystem] {
 	# Official bindings
 	# See http://support.apple.com/kb/HT1343
 	event add <<SelectAll>>		<Command-Key-a>
-	event add <<SelectNone>>	<Option-Command-Key-a>
+	#Attach function keys not otherwise assigned to this event so they no-op - workaround for bug 0e6930dfe7
+	event add <<SelectNone>>	<Option-Command-Key-a> <Key-F5> <Key-F1> <Key-F5> <Key-F6> <Key-F7> <Key-F8> <Key-F9> <Key-F10> <Key-F11> <Key-F12>
 	event add <<Undo>>		<Command-Key-z> <Command-Lock-Key-Z>
 	event add <<Redo>>		<Shift-Command-Key-z> <Shift-Command-Lock-Key-z>
 	event add <<NextChar>>		<Right> <Control-Key-f> <Control-Lock-Key-F>
@@ -676,7 +677,7 @@ proc ::tk::mcmaxamp {args} {
     return $maxlen
 }
 
-# For now, turn off the custom mdef proc for the mac:
+# For now, turn off the custom mdef proc for the Mac:
 
 if {[tk windowingsystem] eq "aqua"} {
     namespace eval ::tk::mac {
@@ -684,6 +685,22 @@ if {[tk windowingsystem] eq "aqua"} {
     }
 }
 
+
+if {[tk windowingsystem] eq "aqua"} {
+    #stub procedures to respond to "do script" Apple Events
+    proc ::tk::mac::DoScriptFile {file} {
+    	source $file
+    }
+    proc ::tk::mac::DoScriptText {script} {
+    	eval $script
+    }
+}
+
+# Create a dictionary to store the starting index of the IME marked
+# text in an Entry or Text widget.
+
+set ::tk::Priv(IMETextMark) [dict create]
+
 # Run the Ttk themed widget set initialization
 if {$::ttk::library ne ""} {
     uplevel \#0 [list source $::ttk::library/ttk.tcl]
